AccessStatus enum

The result of checking or requesting access to a hardware capability.

Inheritance
Available extensions

Values

granted → const AccessStatus

Everything needed is granted; the device can be used.

denied → const AccessStatus

Access was refused, but asking again may show the system prompt.

permanentlyDenied → const AccessStatus

Access was refused and the system will not prompt again. The user must enable it in the app's settings page (see HardwareAccess.openSettings).

restricted → const AccessStatus

Access is blocked by policy (for example parental controls or MDM).

notRequired → const AccessStatus

The platform needs no permission for this capability.

unsupported → const AccessStatus

The capability does not exist on this platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<AccessStatus>
A constant List of the values in this enum, in order of their declaration.